import React, { useState, useEffect, useCallback } from 'react';
import styles from './index.less';
import cx from 'classnames';
import { Select } from 'antd';
//import type { topNavRightProps } from '@/pages/Equipment/components/topNavRight';
import RunNavRight from '@/pages/Runtime/components/topNavRight';

import type { navigatorItem } from '@/pages/Environment/index';

export type topNavigatorProps = {
  navigatorList: navigatorItem[];
  type: string;
  navigatorChange(item: navigatorItem): void;
  // action?: React.ReactElement<topNavRightProps>[];
  action?: React.ReactNode;
};
type floorItem = {
  value: string;
  [key: string]: any;
};

const TopNavigator: React.FC<topNavigatorProps> = ({
  navigatorList = [],
  type,
  navigatorChange,
  action,
}) => {
  const [floorList, setFloorList] = useState<floorItem[]>([
    {
      value: 'F1',
    },
    {
      value: 'F2',
    },
    {
      value: 'F3',
    },
    {
      value: 'F4',
    },
  ]);
  const [currentFloor, setCurrentFloor] = useState<string>('F2');

  const [selParamObj, setSelParamObj] = useState(navigatorList[0]);

  //   useEffect(() => {
  //     console.log('chartModal-effect');
  //     setSelParamObj(navigatorList[0]);
  //   }, []);

  const changHandle = useCallback((val) => {
    //debugger;
    console.log('select-onChange', val);
    setCurrentFloor(val);
  }, []);
  //当前切换导航条时
  const itemClick = (item: navigatorItem) => {
    setSelParamObj(item);
    console.log('itemclick', item);
    navigatorChange && navigatorChange(item);
  };

  console.log('top渲染');

  return (
    <div className={styles.topnavigator}>
      <div className={styles.floor}>
        <Select
          options={floorList}
          value={currentFloor}
          onChange={changHandle}
          size="large"
          dropdownMatchSelectWidth={true}
          style={{ width: '100%' }}
          bordered={false}
        />
      </div>
      <div className={styles.navigator}>
        {navigatorList.map((item, index) => {
          return (
            <div
              className={cx(styles.navItem, { [styles.sel]: item.id === selParamObj.id })}
              style={{
                borderBottom:
                  item.id === selParamObj.id ? `3px solid  ${item.color}` : '3px solid #ffffff',
              }}
              key={'nav' + index}
              onClick={() => {
                itemClick(item);
              }}
            >
              <img src={item.src} style={{ height: 20 }}></img>
              <div className={styles.text}>{item.name}</div>
            </div>
          );
        })}
      </div>
      {type === 'enviroment' && (
        <div className={styles.right}>
          <div className={styles.firstLine} style={{ color: selParamObj.color }}>
            <span className={styles.value}>{selParamObj.num}</span>{' '}
            <span className={styles.unit}>{selParamObj.unit}</span>
          </div>
          <div className={styles.text}>当前楼层平均{selParamObj.name}</div>
        </div>
      )}
      {type === 'equipment' && action}
      {type === 'runtime' && <RunNavRight></RunNavRight>}
    </div>
  );
};

export default TopNavigator;
